@@ -7,7 +7,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -15,7 +15,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -71,7 +71,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -89,12 +89,12 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
@@ -338,26 +338,26 @@ int UDPHeader::setTotalLength(){
   * here because UDP is supposed to be independent of IPv4, IPv6 or
   * whatever other network layer protocol is used to carry the UDP datagrams.*/
   if ((mylen+otherslen) > 65535 || (mylen+otherslen)<8 ){
-    printf("UDPHeader::setTotalLenght(): Invalid length.\n");
+    printf("UDPHeader::setTotalLength(): Invalid length.\n");
     return OP_FAILURE;
   }
 
   h.uh_ulen=htons( mylen+otherslen );
 
   return OP_SUCCESS;
-} /* End of setTotalLenght() */
+} /* End of setTotalLength() */
 
 
 /** @warning Supplied value MUST be in HOST byte order */
 int UDPHeader::setTotalLength(u16 l){
   this->h.uh_ulen=htons(l);
   return OP_SUCCESS;
-} /* End of setTotalLenght() */
+} /* End of setTotalLength() */
 
 
 /** @warning Returned value is in HOST byte order */
 u16 UDPHeader::getTotalLength() const {
   return ntohs(this->h.uh_ulen);
-} /* End of getTotalLenght() */
+} /* End of getTotalLength() */
 
 
