@@ -17,7 +17,7 @@ struct ip
     u_short ip_id;                      /* identification */
     u_short ip_off;                     /* fragment offset field */
 #define IP_RF 0x8000                    /* reserved fragment flag */
-#define IP_DF 0x4000                    /* dont fragment flag */
+#define IP_DF 0x4000                    /* don't fragment flag */
 #define IP_MF 0x2000                    /* more fragments flag */
 #define IP_OFFMASK 0x1fff               /* mask for fragmenting bits */
     u_char ip_ttl;                    /* time to live */
@@ -151,7 +151,7 @@ struct iphdr {
 	short	ip_len;			/* total length */
 	u_short	ip_id;			/* identification */
 	short	ip_off;			/* fragment offset field */
-#define	IP_DF 0x4000		/* dont fragment flag */
+#define	IP_DF 0x4000		/* don't fragment flag */
 #define	IP_MF 0x2000		/* more fragments flag */
 	u_char	ip_ttl;			/* time to live */
 	u_char	ip_p;			/* protocol */
