@@ -2,7 +2,7 @@
  * ncat_posix.c -- POSIX-specific functions.                               *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -10,7 +10,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -66,7 +66,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -84,12 +84,12 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
@@ -122,7 +122,10 @@
 /* $Id$ */
 
 #include "ncat.h"
+
+#ifdef HAVE_LUA
 #include "ncat_lua.h"
+#endif
 
 char **cmdline_split(const char *cmdexec);
 
@@ -224,6 +227,8 @@ void netexec(struct fdinfo *info, char *cmdexec)
         Dup2(child_stdin[0], STDIN_FILENO);
         Dup2(child_stdout[1], STDOUT_FILENO);
 
+        setup_environment(info);
+
         switch (o.execmode) {
         char **cmdargs;
 
@@ -253,7 +258,7 @@ void netexec(struct fdinfo *info, char *cmdexec)
         maxfd = info->fd;
 
     /* This is the parent process. Enter a "caretaker" loop that reads from the
-       socket and writes to the suprocess, and reads from the subprocess and
+       socket and writes to the subprocess, and reads from the subprocess and
        writes to the socket. We exit the loop on any read error (or EOF). On a
        write error we just close the opposite side of the conversation. */
     crlf_state = 0;
@@ -389,6 +394,14 @@ char **cmdline_split(const char *cmdexec)
     return cmd_args;
 }
 
+int ncat_openlog(const char *logfile, int append)
+{
+    if (append)
+        return Open(logfile, O_WRONLY | O_CREAT | O_APPEND, 0664);
+    else
+        return Open(logfile, O_WRONLY | O_CREAT | O_TRUNC, 0664);
+}
+
 void set_lf_mode(void)
 {
     /* Nothing needed. */
@@ -421,3 +434,8 @@ int ssl_load_default_ca_certs(SSL_CTX *ctx)
     return 0;
 }
 #endif
+
+int setenv_portable(const char *name, const char *value)
+{
+    return setenv(name, value, 1);
+}
