@@ -2,7 +2,7 @@
  * util.c -- Various utility functions.                                    *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -10,7 +10,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -66,7 +66,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -84,12 +84,12 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
@@ -119,7 +119,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: util.c 31563 2013-07-28 22:08:48Z fyodor $ */
+/* $Id: util.c 33540 2014-08-16 02:45:47Z dmiller $ */
 
 #include "sys_wrap.h"
 #include "util.h"
@@ -189,6 +189,7 @@ void loguser(const char *fmt, ...)
     va_start(ap, fmt);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
+    fflush(stderr);
 }
 
 /* Log a user message without the "Ncat: " prefix, to allow building up a line
@@ -200,6 +201,7 @@ void loguser_noprefix(const char *fmt, ...)
     va_start(ap, fmt);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
+    fflush(stderr);
 }
 
 void logdebug(const char *fmt, ...)
@@ -210,12 +212,25 @@ void logdebug(const char *fmt, ...)
     va_start(ap, fmt);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
+    fflush(stderr);
+}
+
+void logtest(const char *fmt, ...)
+{
+    va_list ap;
+
+    fprintf(stderr, "NCAT TEST: ");
+    va_start(ap, fmt);
+    vfprintf(stderr, fmt, ap);
+    va_end(ap);
+    fflush(stderr);
 }
 
 /* Exit status 2 indicates a program error other than a network error. */
 void die(char *err)
 {
     perror(err);
+    fflush(stderr);
     exit(2);
 }
 
@@ -229,6 +244,7 @@ void bye(const char *fmt, ...)
     vfprintf(stderr, fmt, ap);
     va_end(ap);
     fprintf(stderr, " QUITTING.\n");
+    fflush(stderr);
 
     exit(2);
 }
@@ -387,6 +403,8 @@ unsigned short inet_port(const union sockaddr_u *su)
     return 0;
 }
 
+/* Return a listening socket after setting various characteristics on it.
+   Returns -1 on error. */
 int do_listen(int type, int proto, const union sockaddr_u *srcaddr_u)
 {
     int sock = 0, option_on = 1;
@@ -400,7 +418,7 @@ int do_listen(int type, int proto, const union sockaddr_u *srcaddr_u)
        nbase. */
     sock = inheritable_socket(srcaddr_u->storage.ss_family, type, proto);
     if (sock < 0)
-      bye("socket: %s", socket_strerror(socket_errno()));
+        return -1;
 
     Setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &option_on, sizeof(int));
 
@@ -456,6 +474,8 @@ int do_listen(int type, int proto, const union sockaddr_u *srcaddr_u)
 #endif
             loguser("Listening on %s:%hu\n", inet_socktop(srcaddr_u), inet_port(srcaddr_u));
     }
+    if (o.test)
+        logtest("LISTEN\n");
 
     return sock;
 }
