@@ -4,7 +4,7 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+ * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
  * also a registered trademark of Insecure.Com LLC.  This program is free  *
  * software; you may redistribute and/or modify it under the terms of the  *
  * GNU General Public License as published by the Free Software            *
@@ -12,7 +12,7 @@
  * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
  * modify, and redistribute this software under certain conditions.  If    *
  * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+ * alternative licenses (contact sales@nmap.com).  Dozens of software      *
  * vendors already license Nmap technology such as host discovery, port    *
  * scanning, OS detection, version detection, and the Nmap Scripting       *
  * Engine.                                                                 *
@@ -68,7 +68,7 @@
  * obeying all GPL rules and restrictions.  For example, source code of    *
  * the whole work must be provided and free redistribution must be         *
  * allowed.  All GPL references to "this License", are to be treated as    *
- * including the special and conditions of the license text as well.       *
+ * including the terms and conditions of this license text as well.        *
  *                                                                         *
  * Because this license imposes special exceptions to the GPL, Covered     *
  * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -86,12 +86,12 @@
  * applications and appliances.  These contracts have been sold to dozens  *
  * of software vendors, and generally include a perpetual license as well  *
  * as providing for priority support and updates.  They also fund the      *
- * continued development of Nmap.  Please email sales@insecure.com for     *
- * further information.                                                    *
+ * continued development of Nmap.  Please email sales@nmap.com for further *
+ * information.                                                            *
  *                                                                         *
- * If you received these files with a written license agreement or         *
- * contract stating terms other than the terms above, then that            *
- * alternative license agreement takes precedence over these comments.     *
+ * If you have received a written license agreement or contract for        *
+ * Covered Software stating terms other than these, you may choose to use  *
+ * and redistribute Covered Software under those terms instead of these.   *
  *                                                                         *
  * Source is provided to this software because we believe users have a     *
  * right to know exactly what a program is going to do before they run it. *
@@ -170,7 +170,7 @@ int EchoClient::start(NpingTarget *target, u16 port){
 
   /* Init Nsock in the probe engine */
   if( this->probe.init_nsock() != OP_SUCCESS ){
-    nping_warning(QT_2, "Couln't initialize Nsock.");
+    nping_warning(QT_2, "Couldn't initialize Nsock.");
     return OP_FAILURE;
   }else{
     /* Extract the nsock pool handler and store it here */
@@ -950,7 +950,7 @@ int EchoClient::nep_recv_std_header_handler(nsock_pool nsp, nsock_event nse, voi
     nping_print(DBG_4, "%s() Received %d bytes", __func__, recvbytes);
   }
 
-  /* Here there are different possibilites. We may have received exactly one
+  /* Here there are different possibilities. We may have received exactly one
    * packet, we may have received more than one packet (as there is no way to
    * make Nsock return an exact amount of bytes), or we may have received
    * less than one packet. In the last case, we determine the number of bytes
@@ -1039,7 +1039,7 @@ int EchoClient::nep_recv_hs_final_handler(nsock_pool nsp, nsock_event nse, void
 
 
 /** Handles reception of NEP_READY message. It handles the received
-  * data provided by nsock and passes it to the parse_readyl() which is the
+  * data provided by nsock and passes it to the parse_ready() which is the
   * one in charge of validating NEP_HANDSHAKE_FINAL packets and updating
   * the internal context accordingly. Returns OP_SUCCESS on success and
   * OP_FAILURE in case of error. */
