@@ -3,7 +3,7 @@
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2012 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -32,17 +32,18 @@
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
- * to nmap-dev@insecure.org for possible incorporation into the main       *
- * distribution.  By sending these changes to Fyodor or one of the         *
- * Insecure.Org development mailing lists, it is assumed that you are      *
- * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
- * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
- * will always be available Open Source, but this is important because the *
- * inability to relicense code has caused devastating problems for other   *
- * Free Software projects (such as KDE and NASM).  We also occasionally    *
- * relicense the code to third parties as discussed above.  If you wish to *
- * specify special license conditions of your contributions, just say so   *
- * when you send them.                                                     *
+ * to the dev@nmap.org mailing list for possible incorporation into the    *
+ * main distribution.  By sending these changes to Fyodor or one of the    *
+ * Insecure.Org development mailing lists, or checking them into the Nmap  *
+ * source code repository, it is understood (unless you specify otherwise) *
+ * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+ * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+ * code.  Nmap will always be available Open Source, but this is important *
+ * because the inability to relicense code has caused devastating problems *
+ * for other Free Software projects (such as KDE and NASM).  We also       *
+ * occasionally relicense the code to third parties as discussed above.    *
+ * If you wish to specify special license conditions of your               *
+ * contributions, just say so when you send them.                          *
  *                                                                         *
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
@@ -52,7 +53,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: engine_poll.c 30306 2012-11-29 03:19:52Z david $ */
+/* $Id: engine_poll.c 31737 2013-08-10 23:59:30Z henri $ */
 
 #ifndef WIN32
 /* Allow the use of POLLRDHUP, if available. */
@@ -76,6 +77,7 @@
 #endif /* ^WIN32 */
 
 #include "nsock_internal.h"
+#include "nsock_log.h"
 
 #if HAVE_PCAP
 #include "nsock_pcap.h"
@@ -106,12 +108,6 @@
 #endif /* POLLRDHUP */
 
 
-#define LOWER_MAX_FD(pinfo) \
-  do {  \
-    pinfo->max_fd--;  \
-  } while (pinfo->max_fd >= 0 && pinfo->events[pinfo->max_fd].fd == -1)
-
-
 /* --- ENGINE INTERFACE PROTOTYPES --- */
 static int poll_init(mspool *nsp);
 static void poll_destroy(mspool *nsp);
@@ -138,7 +134,8 @@ static void iterate_through_event_lists(mspool *nsp);
 
 /* defined in nsock_core.c */
 void process_iod_events(mspool *nsp, msiod *nsi, int ev);
-void process_event(mspool *nsp, gh_list *evlist, msevent *nse, int ev);
+void process_event(mspool *nsp, gh_list_t *evlist, msevent *nse, int ev);
+void process_expired_events(mspool *nsp);
 #if HAVE_PCAP
 #ifndef PCAP_CAN_DO_SELECT
 int pcap_read_on_nonselect(mspool *nsp);
@@ -163,6 +160,15 @@ struct poll_engine_info {
 };
 
 
+
+static inline int lower_max_fd(struct poll_engine_info *pinfo) {
+  do {
+    pinfo->max_fd--;
+  } while (pinfo->max_fd >= 0 && pinfo->events[pinfo->max_fd].fd == -1);
+
+  return pinfo->max_fd;
+}
+
 static inline int evlist_grow(struct poll_engine_info *pinfo) {
   int i;
 
@@ -252,9 +258,8 @@ int poll_iod_unregister(mspool *nsp, msiod *iod) {
     pinfo->events[sd].events = 0;
     pinfo->events[sd].revents = 0;
 
-    if (pinfo->max_fd == sd) {
-      LOWER_MAX_FD(pinfo);
-    }
+    if (pinfo->max_fd == sd)
+      lower_max_fd(pinfo);
 
     IOD_PROPCLR(iod, IOD_REGISTERED);
   }
@@ -309,19 +314,21 @@ int poll_loop(mspool *nsp, int msec_timeout) {
     return 0; /* No need to wait on 0 events ... */
 
   do {
-    if (nsp->tracelevel > 6)
-      nsock_trace(nsp, "wait_for_events");
+    msevent *nse;
 
-    if (nsp->next_ev.tv_sec == 0)
+    nsock_log_debug_all(nsp, "wait for events");
+
+    nse = next_expirable_event(nsp);
+    if (!nse)
       event_msecs = -1; /* None of the events specified a timeout */
     else
-      event_msecs = MAX(0, TIMEVAL_MSEC_SUBTRACT(nsp->next_ev, nsock_tod));
+      event_msecs = MAX(0, TIMEVAL_MSEC_SUBTRACT(nse->timeout, nsock_tod));
 
 #if HAVE_PCAP
 #ifndef PCAP_CAN_DO_SELECT
     /* Force a low timeout when capturing packets on systems where
      * the pcap descriptor is not select()able. */
-    if (GH_LIST_COUNT(&nsp->pcap_read_events) > 0)
+    if (gh_list_count(&nsp->pcap_read_events) > 0)
       if (event_msecs > PCAP_POLL_INTERVAL)
         event_msecs = PCAP_POLL_INTERVAL;
 #endif
@@ -354,7 +361,7 @@ int poll_loop(mspool *nsp, int msec_timeout) {
   } while (results_left == -1 && sock_err == EINTR); /* repeat only if signal occurred */
 
   if (results_left == -1 && sock_err != EINTR) {
-    nsock_trace(nsp, "nsock_loop error %d: %s", sock_err, socket_strerror(sock_err));
+    nsock_log_error(nsp, "nsock_loop error %d: %s", sock_err, socket_strerror(sock_err));
     nsp->errnum = sock_err;
     return -1;
   }
@@ -400,41 +407,26 @@ static inline int get_evmask(mspool *nsp, msiod *nsi) {
  * timer_events, etc) and take action for those that have completed (due to
  * timeout, i/o, etc) */
 void iterate_through_event_lists(mspool *nsp) {
-  gh_list_elem *current, *next, *last, *timer_last;
+  gh_lnode_t *current, *next, *last;
 
-  /* Clear it -- We will find the next event as we go through the list */
-  nsp->next_ev.tv_sec = 0;
+  last = gh_list_last_elem(&nsp->active_iods);
 
-  last = GH_LIST_LAST_ELEM(&nsp->active_iods);
-  timer_last = GH_LIST_LAST_ELEM(&nsp->timer_events);
-
-  for (current = GH_LIST_FIRST_ELEM(&nsp->active_iods);
-       current != NULL && GH_LIST_ELEM_PREV(current) != last; current = next) {
-
-    msiod *nsi = (msiod *)GH_LIST_ELEM_DATA(current);
+  for (current = gh_list_first_elem(&nsp->active_iods);
+       current != NULL && gh_lnode_prev(current) != last;
+       current = next) {
+    msiod *nsi = container_of(current, msiod, nodeq);
 
     process_iod_events(nsp, nsi, get_evmask(nsp, nsi));
 
-    next = GH_LIST_ELEM_NEXT(current);
+    next = gh_lnode_next(current);
     if (nsi->state == NSIOD_STATE_DELETED) {
-      gh_list_remove_elem(&nsp->active_iods, current);
-      gh_list_prepend(&nsp->free_iods, nsi);
+      gh_list_remove(&nsp->active_iods, current);
+      gh_list_prepend(&nsp->free_iods, current);
     }
   }
 
-  /* iterate through timers */
-  for (current = GH_LIST_FIRST_ELEM(&nsp->timer_events);
-       current != NULL && GH_LIST_ELEM_PREV(current) != timer_last; current = next) {
-
-    msevent *nse = (msevent *)GH_LIST_ELEM_DATA(current);
-
-    process_event(nsp, &nsp->timer_events, nse, EV_NONE);
-
-    next = GH_LIST_ELEM_NEXT(current);
-    if (nse->event_done)
-      gh_list_remove_elem(&nsp->timer_events, current);
-  }
+  /* iterate through timers and expired events */
+  process_expired_events(nsp);
 }
 
 #endif /* HAVE_POLL */
-
