@@ -1,11 +1,11 @@
 /***************************************************************************
  * nsock_internal.h -- PRIVATE interface definitions for the guts of the   *
- * nsock paralle socket event library.  Applications calling this library  *
+ * nsock parallel socket event library. Applications calling this library  *
  * should NOT include this. even LOOK at these :).                         *
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2012 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -34,17 +34,18 @@
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
- * to nmap-dev@insecure.org for possible incorporation into the main       *
- * distribution.  By sending these changes to Fyodor or one of the         *
- * Insecure.Org development mailing lists, it is assumed that you are      *
- * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
- * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
- * will always be available Open Source, but this is important because the *
- * inability to relicense code has caused devastating problems for other   *
- * Free Software projects (such as KDE and NASM).  We also occasionally    *
- * relicense the code to third parties as discussed above.  If you wish to *
- * specify special license conditions of your contributions, just say so   *
- * when you send them.                                                     *
+ * to the dev@nmap.org mailing list for possible incorporation into the    *
+ * main distribution.  By sending these changes to Fyodor or one of the    *
+ * Insecure.Org development mailing lists, or checking them into the Nmap  *
+ * source code repository, it is understood (unless you specify otherwise) *
+ * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+ * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+ * code.  Nmap will always be available Open Source, but this is important *
+ * because the inability to relicense code has caused devastating problems *
+ * for other Free Software projects (such as KDE and NASM).  We also       *
+ * occasionally relicense the code to third parties as discussed above.    *
+ * If you wish to specify special license conditions of your               *
+ * contributions, just say so when you send them.                          *
  *                                                                         *
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
@@ -54,7 +55,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nsock_internal.h 30231 2012-11-12 20:44:37Z david $ */
+/* $Id: nsock_internal.h 32741 2014-02-20 18:44:12Z dmiller $ */
 
 #ifndef NSOCK_INTERNAL_H
 #define NSOCK_INTERNAL_H
@@ -72,9 +73,11 @@
 #endif
 
 #include "gh_list.h"
+#include "gh_heap.h"
 #include "filespace.h"
 #include "nsock.h" /* The public interface -- I need it for some enum defs */
 #include "nsock_ssl.h"
+#include "nsock_proxy.h"
 
 #if HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -163,28 +166,21 @@ typedef struct {
   void *engine_data;
 
   /* Active network events */
-  gh_list connect_events;
-  gh_list read_events;
-  gh_list write_events;
-  gh_list timer_events;
+  gh_list_t connect_events;
+  gh_list_t read_events;
+  gh_list_t write_events;
 #if HAVE_PCAP
-  gh_list pcap_read_events;
+  gh_list_t pcap_read_events;
 #endif
+  gh_heap_t expirables;
 
   /* Active iods and related lists of events */
-  gh_list active_iods;
+  gh_list_t active_iods;
 
   /* msiod structures that have been freed for reuse */
-  gh_list free_iods;
+  gh_list_t free_iods;
   /* When an event is deleted, we stick it here for later reuse */
-  gh_list free_events;
-
-  /* The soonest time that either a timer event goes
-   * off or a read/write/connect expires.  It is
-   * updated each main loop round as we go through
-   * the events.  It is an absolute time.  If there
-   * are no events, tv_sec is 0 */
-  struct timeval next_ev;
+  gh_list_t free_events;
 
   /* Number of events pending (total) on all lists */
   int events_pending;
@@ -198,12 +194,9 @@ typedef struct {
    * error (errnum fashion) */
   int errnum;
 
-  /* Trace/debug level - set by nsp_settrace. If positive, trace logs are
-   * printted to tracefile. */
-  int tracelevel;
-  FILE *tracefile;
-  /* This time is subtracted from the current time for trace reports */
-  struct timeval tracebasetime;
+  /* Logging information. */
+  nsock_logger_t logger;
+  nsock_loglevel_t loglevel;
 
   /* If true, new sockets will have SO_BROADCAST set */
   int broadcast;
@@ -219,6 +212,11 @@ typedef struct {
   /* The SSL Context (options and such) */
   SSL_CTX *sslctx;
 #endif
+
+  /* Optional proxy chain (NULL is not set). Can only be set once per NSP (using
+   * nsock_proxychain_new() or nsp_set_proxychain(). */
+  struct proxy_chain *px_chain;
+
 } mspool;
 
 
@@ -232,11 +230,11 @@ typedef struct {
   int events_pending;
 
   /* Pending events */
-  gh_list_elem *first_connect;
-  gh_list_elem *first_read;
-  gh_list_elem *first_write;
+  gh_lnode_t *first_connect;
+  gh_lnode_t *first_read;
+  gh_lnode_t *first_write;
 #if HAVE_PCAP
-  gh_list_elem *first_pcap_read;
+  gh_lnode_t *first_pcap_read;
 #endif
 
   int readsd_count;
@@ -269,7 +267,7 @@ typedef struct {
   /* The mspool keeps track of msiods that have been allocated so that it can
    * destroy them if the msp is deleted.  This pointer makes it easy to remove
    * this msiod from the allocated list when necessary */
-  gh_list_elem *entry_in_nsp_active_iods;
+  gh_lnode_t nodeq;
 
 #define IOD_REGISTERED  0x01
 #define IOD_PROCESSED   0x02    /* internally used by engine_kqueue.c */
@@ -308,13 +306,15 @@ typedef struct {
 
   /* Pointer to mspcap struct (used only if pcap support is included) */
   void *pcap;
+
+  struct proxy_chain_context *px_ctx;
+
 } msiod;
 
 
 /* nsock_event_t handles a single event.  Its ID is generally returned when the
  * event is created, and the event is included in callbacks */
 typedef struct {
-
   /* Every event has an ID which is unique for a given nsock unless you blow
    * through more than 500,000,000 events */
   nsock_event_id id;
@@ -342,14 +342,24 @@ typedef struct {
   /* If we return a status of NSE_STATUS_ERROR, this must be set */
   int errnum;
 
-  int eof;
-
   /* The nsock I/O descriptor related to event (if applicable) */
   msiod *iod;
 
   /* The handler to call when event is complete */
   nsock_ev_handler handler;
 
+  /* slot in the expirable binheap */
+  gh_hnode_t expire;
+
+  /* For some reasons (see nsock_pcap.c) we register pcap events as both read
+   * and pcap_read events when in PCAP_BSD_SELECT_HACK mode. We then need two
+   * gh_lnode_t handles. To make code simpler, we _always_ use _nodeq_pcap for
+   * pcap_read events and _nodeq_io for the other ones.
+   * When not in PCAP_BSD_SELECT_HACK mode we define both handles as members
+   * of an union to optimize memory footprint. */
+  gh_lnode_t nodeq_io;
+  gh_lnode_t nodeq_pcap;
+
   /* Optional (NULL if unset) pointer to pass to the handler */
   void *userdata;
 
@@ -357,9 +367,8 @@ typedef struct {
    * event_done is nonzero.  Used when event is finished at unexpected time and
    * we want to dispatch it later to avoid duplicating stat update code and all
    * that other crap */
-  int event_done;
-
-  struct timeval time_created;
+  unsigned int event_done: 1;
+  unsigned int eof: 1;
 } msevent;
 
 
@@ -388,9 +397,36 @@ struct io_engine {
   int (*loop)(mspool *nsp, int msec_timeout);
 };
 
+/* ----------- NSOCK I/O ENGINE CONVENIENCE WRAPPERS ------------ */
+static inline int nsock_engine_init(mspool *nsp) {
+  return nsp->engine->init(nsp);
+}
+
+static inline void nsock_engine_destroy(mspool *nsp) {
+  nsp->engine->destroy(nsp);
+  return;
+}
+
+static inline int nsock_engine_iod_register(mspool *nsp, msiod *iod, int ev) {
+  return nsp->engine->iod_register(nsp, iod, ev);
+}
+
+static inline int nsock_engine_iod_unregister(mspool *nsp, msiod *iod) {
+  return nsp->engine->iod_unregister(nsp, iod);
+}
+
+static inline int nsock_engine_iod_modify(mspool *nsp, msiod *iod, int ev_set, int ev_clr) {
+  return nsp->engine->iod_modify(nsp, iod, ev_set, ev_clr);
+}
+
+static inline int nsock_engine_loop(mspool *nsp, int msec_timeout) {
+  return nsp->engine->loop(nsp, msec_timeout);
+}
 
 /* ------------------- PROTOTYPES ------------------- */
 
+int msevent_timedout(msevent *nse);
+
 /* Get a new nsock_event_id, given a type */
 nsock_event_id get_new_event_id(mspool *nsp, enum nse_type type);
 
@@ -409,7 +445,7 @@ msevent *msevent_new(mspool *nsp, enum nse_type type, msiod *msiod, int timeout_
  * is the list element in event_list which holds the event.  Pass a nonzero for
  * notify if you want the program owning the event to be notified that it has
  * been cancelled */
-int msevent_cancel(mspool *nsp, msevent *nse, gh_list *event_list, gh_list_elem *elem, int notify);
+int msevent_cancel(mspool *nsp, msevent *nse, gh_list_t *event_list, gh_lnode_t *elem, int notify);
 
 /* Adjust various statistics, dispatches the event handler (if notify is
  * nonzero) and then deletes the event.  This function does NOT delete the event
@@ -446,8 +482,6 @@ void handle_timer_result(mspool *ms, msevent *nse, enum nse_status status);
 void handle_pcap_read_result(mspool *ms, msevent *nse, enum nse_status status);
 #endif
 
-void nsock_trace(mspool *ms, char *fmt, ...) __attribute__ ((format (printf, 2, 3)));
-
 /* An event has been completed and the handler is about to be called.  This
  * function writes out tracing data about the event if necessary */
 void nsock_trace_handler_callback(mspool *ms, msevent *nse);
@@ -458,5 +492,23 @@ void nsock_trace_handler_callback(mspool *ms, msevent *nse);
 void nsi_set_ssl_session(msiod *iod, SSL_SESSION *sessid);
 #endif
 
+static inline msevent *next_expirable_event(mspool *nsp) {
+  gh_hnode_t *hnode;
+
+  hnode = gh_heap_min(&nsp->expirables);
+  if (!hnode)
+    return NULL;
+
+  return container_of(hnode, msevent, expire);
+}
+
+static inline msevent *lnode_msevent(gh_lnode_t *lnode) {
+  return container_of(lnode, msevent, nodeq_io);
+}
+
+static inline msevent *lnode_msevent2(gh_lnode_t *lnode) {
+  return container_of(lnode, msevent, nodeq_pcap);
+}
+
 #endif /* NSOCK_INTERNAL_H */
 
