@@ -1,12 +1,12 @@
 /***************************************************************************
  * nsock_iod.c -- This contains the functions relating to nsock_iod (and   *
- * its nsock internal manifistation -- nsockiod.  This is is similar to a  *
+ * its nsock internal manifestation -- nsockiod.  This is is similar to a  *
  * file descriptor in that you create it and then use it to initiate       *
  * connections, read/write data, etc.                                      *
  *                                                                         *
  ***********************IMPORTANT NSOCK LICENSE TERMS***********************
  *                                                                         *
- * The nsock parallel socket event library is (C) 1999-2012 Insecure.Com   *
+ * The nsock parallel socket event library is (C) 1999-2013 Insecure.Com   *
  * LLC This library is free software; you may redistribute and/or          *
  * modify it under the terms of the GNU General Public License as          *
  * published by the Free Software Foundation; Version 2.  This guarantees  *
@@ -35,17 +35,18 @@
  *                                                                         *
  * Source code also allows you to port Nmap to new platforms, fix bugs,    *
  * and add new features.  You are highly encouraged to send your changes   *
- * to nmap-dev@insecure.org for possible incorporation into the main       *
- * distribution.  By sending these changes to Fyodor or one of the         *
- * Insecure.Org development mailing lists, it is assumed that you are      *
- * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
- * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
- * will always be available Open Source, but this is important because the *
- * inability to relicense code has caused devastating problems for other   *
- * Free Software projects (such as KDE and NASM).  We also occasionally    *
- * relicense the code to third parties as discussed above.  If you wish to *
- * specify special license conditions of your contributions, just say so   *
- * when you send them.                                                     *
+ * to the dev@nmap.org mailing list for possible incorporation into the    *
+ * main distribution.  By sending these changes to Fyodor or one of the    *
+ * Insecure.Org development mailing lists, or checking them into the Nmap  *
+ * source code repository, it is understood (unless you specify otherwise) *
+ * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+ * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+ * code.  Nmap will always be available Open Source, but this is important *
+ * because the inability to relicense code has caused devastating problems *
+ * for other Free Software projects (such as KDE and NASM).  We also       *
+ * occasionally relicense the code to third parties as discussed above.    *
+ * If you wish to specify special license conditions of your               *
+ * contributions, just say so when you send them.                          *
  *                                                                         *
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
@@ -55,10 +56,11 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nsock_iod.c 29169 2012-07-09 16:45:49Z henri $ */
+/* $Id: nsock_iod.c 32741 2014-02-20 18:44:12Z dmiller $ */
 
 #include "nsock.h"
 #include "nsock_internal.h"
+#include "nsock_log.h"
 #include "gh_list.h"
 #include "netutils.h"
 
@@ -67,6 +69,7 @@
 #endif
 
 #include <string.h>
+    
 
 /* nsock_iod is like a "file descriptor" for the nsock library. You use it to
  * request events. And here is how you create an nsock_iod. nsi_new returns
@@ -84,12 +87,15 @@ nsock_iod nsi_new(nsock_pool nsockp, void *userdata) {
  * will be destroyed when the nsi is destroyed. */
 nsock_iod nsi_new2(nsock_pool nsockp, int sd, void *userdata) {
   mspool *nsp = (mspool *)nsockp;
+  gh_lnode_t *lnode;
   msiod *nsi;
 
-  nsi = (msiod *)gh_list_pop(&nsp->free_iods);
-  if (!nsi) {
+  lnode = gh_list_pop(&nsp->free_iods);
+  if (!lnode) {
     nsi = (msiod *)safe_malloc(sizeof(msiod));
     memset(nsi, 0, sizeof(*nsi));
+  } else {
+    nsi = container_of(lnode, msiod, nodeq);
   }
 
   if (sd == -1) {
@@ -135,15 +141,20 @@ nsock_iod nsi_new2(nsock_pool nsockp, int sd, void *userdata) {
   nsi->ssl_session = NULL;
 #endif
 
+  if (nsp->px_chain) {
+    nsi->px_ctx = proxy_chain_context_new(nsp);
+  } else {
+    nsi->px_ctx = NULL;
+  }
+
   nsi->id = nsp->next_iod_serial++;
   if (nsi->id == 0)
     nsi->id = nsp->next_iod_serial++;
 
   /* The nsp keeps track of active msiods so it can delete them if it is deleted */
-  nsi->entry_in_nsp_active_iods = gh_list_append(&nsp->active_iods, nsi);
+  gh_list_append(&nsp->active_iods, &nsi->nodeq);
 
-  if (nsp->tracelevel > 1)
-    nsock_trace(nsp, "nsi_new (IOD #%lu)", nsi->id);
+  nsock_log_info(nsp, "nsi_new (IOD #%lu)", nsi->id);
 
   return (nsock_iod)nsi;
 }
@@ -158,13 +169,13 @@ int socket_count_zero(msiod *iod, mspool *ms);
  * pending on this nsock_iod.  This can be NSOCK_PENDING_NOTIFY (send a KILL
  * notification to each event), NSOCK_PENDING_SILENT (do not send notification
  * to the killed events), or NSOCK_PENDING_ERROR (print an error message and
- * quiit the program) */
-void nsi_delete(nsock_iod nsockiod, int pending_response) {
+ * quit the program) */
+void nsi_delete(nsock_iod nsockiod, enum nsock_del_mode pending_response) {
   msiod *nsi = (msiod *)nsockiod;
-  gh_list_elem *evlist_ar[3];
-  gh_list *corresp_list[3];
+  gh_lnode_t *evlist_ar[3];
+  gh_list_t *corresp_list[3];
   int i;
-  gh_list_elem *current, *next;
+  gh_lnode_t *current, *next;
 
   assert(nsi);
 
@@ -174,8 +185,7 @@ void nsi_delete(nsock_iod nsockiod, int pending_response) {
     return;
   }
 
-  if (nsi->nsp->tracelevel > 1)
-    nsock_trace(nsi->nsp, "nsi_delete (IOD #%lu)", nsi->id);
+  nsock_log_info(nsi->nsp, "nsi_delete (IOD #%lu)", nsi->id);
 
   if (nsi->events_pending > 0) {
     /* shit -- they killed the msiod while an event was still pending on it.
@@ -198,8 +208,10 @@ void nsi_delete(nsock_iod nsockiod, int pending_response) {
 
     for (i = 0; i < 3 && nsi->events_pending > 0; i++) {
       for (current = evlist_ar[i]; current != NULL; current = next) {
-        next = GH_LIST_ELEM_NEXT(current);
-        msevent *nse = (msevent *)GH_LIST_ELEM_DATA(current);
+        msevent *nse;
+
+        next = gh_lnode_next(current);
+        nse = lnode_msevent(current);
 
         /* we're done with this list of events for the current IOD */
         if (nse->iod != nsi)
@@ -231,10 +243,8 @@ void nsi_delete(nsock_iod nsockiod, int pending_response) {
 #endif
 
     if (SSL_shutdown(nsi->ssl) == -1) {
-
-      if (nsi->nsp->tracelevel > 1)
-        nsock_trace(nsi->nsp, "nsi_delete: SSL shutdown failed (%s) on NSI %li",
-                    ERR_reason_error_string(SSL_get_error(nsi->ssl, -1)), nsi->id);
+      nsock_log_info(nsi->nsp, "nsi_delete: SSL shutdown failed (%s) on NSI %li",
+                     ERR_reason_error_string(SSL_get_error(nsi->ssl, -1)), nsi->id);
     }
 
     /* I don't really care if the SSL_shutdown() succeeded politely. I could
@@ -276,6 +286,9 @@ void nsi_delete(nsock_iod nsockiod, int pending_response) {
     nsi->pcap = NULL;
   }
 #endif
+
+  if (nsi->px_ctx)
+    proxy_chain_context_delete(nsi->px_ctx);
 }
 
 /* Returns the ID of an nsock_iod . This ID is always unique amongst ids for a
