@@ -1,22 +1,123 @@
 # vim: set fileencoding=utf-8 :
 
-# Copyright (C) 2007, 2008 Insecure.Com LLC.
-#
-# Author: João Paulo de Souza Medeiros <ignotus21@gmail.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# ***********************IMPORTANT NMAP LICENSE TERMS************************
+# *                                                                         *
+# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
+# * also a registered trademark of Insecure.Com LLC.  This program is free  *
+# * software; you may redistribute and/or modify it under the terms of the  *
+# * GNU General Public License as published by the Free Software            *
+# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
+# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
+# * modify, and redistribute this software under certain conditions.  If    *
+# * you wish to embed Nmap technology into proprietary software, we sell    *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
+# * vendors already license Nmap technology such as host discovery, port    *
+# * scanning, OS detection, version detection, and the Nmap Scripting       *
+# * Engine.                                                                 *
+# *                                                                         *
+# * Note that the GPL places important restrictions on "derivative works",  *
+# * yet it does not provide a detailed definition of that term.  To avoid   *
+# * misunderstandings, we interpret that term as broadly as copyright law   *
+# * allows.  For example, we consider an application to constitute a        *
+# * derivative work for the purpose of this license if it does any of the   *
+# * following with any software or content covered by this license          *
+# * ("Covered Software"):                                                   *
+# *                                                                         *
+# * o Integrates source code from Covered Software.                         *
+# *                                                                         *
+# * o Reads or includes copyrighted data files, such as Nmap's nmap-os-db   *
+# * or nmap-service-probes.                                                 *
+# *                                                                         *
+# * o Is designed specifically to execute Covered Software and parse the    *
+# * results (as opposed to typical shell or execution-menu apps, which will *
+# * execute anything you tell them to).                                     *
+# *                                                                         *
+# * o Includes Covered Software in a proprietary executable installer.  The *
+# * installers produced by InstallShield are an example of this.  Including *
+# * Nmap with other software in compressed or archival form does not        *
+# * trigger this provision, provided appropriate open source decompression  *
+# * or de-archiving software is widely available for no charge.  For the    *
+# * purposes of this license, an installer is considered to include Covered *
+# * Software even if it actually retrieves a copy of Covered Software from  *
+# * another source during runtime (such as by downloading it from the       *
+# * Internet).                                                              *
+# *                                                                         *
+# * o Links (statically or dynamically) to a library which does any of the  *
+# * above.                                                                  *
+# *                                                                         *
+# * o Executes a helper program, module, or script to do any of the above.  *
+# *                                                                         *
+# * This list is not exclusive, but is meant to clarify our interpretation  *
+# * of derived works with some common examples.  Other people may interpret *
+# * the plain GPL differently, so we consider this a special exception to   *
+# * the GPL that we apply to Covered Software.  Works which meet any of     *
+# * these conditions must conform to all of the terms of this license,      *
+# * particularly including the GPL Section 3 requirements of providing      *
+# * source code and allowing free redistribution of the work as a whole.    *
+# *                                                                         *
+# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
+# * permission to link the code of this program with any version of the     *
+# * OpenSSL library which is distributed under a license identical to that  *
+# * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
+# * linked combinations including the two.                                  *
+# *                                                                         *
+# * Any redistribution of Covered Software, including any derived works,    *
+# * must obey and carry forward all of the terms of this license, including *
+# * obeying all GPL rules and restrictions.  For example, source code of    *
+# * the whole work must be provided and free redistribution must be         *
+# * allowed.  All GPL references to "this License", are to be treated as    *
+# * including the terms and conditions of this license text as well.        *
+# *                                                                         *
+# * Because this license imposes special exceptions to the GPL, Covered     *
+# * Work may not be combined (even as part of a larger work) with plain GPL *
+# * software.  The terms, conditions, and exceptions of this license must   *
+# * be included as well.  This license is incompatible with some other open *
+# * source licenses as well.  In some cases we can relicense portions of    *
+# * Nmap or grant special permissions to use it in other open source        *
+# * software.  Please contact fyodor@nmap.org with any such requests.       *
+# * Similarly, we don't incorporate incompatible open source software into  *
+# * Covered Software without special permission from the copyright holders. *
+# *                                                                         *
+# * If you have any questions about the licensing restrictions on using     *
+# * Nmap in other works, are happy to help.  As mentioned above, we also    *
+# * offer alternative license to integrate Nmap into proprietary            *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates.  They also fund the      *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
+# *                                                                         *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
+# *                                                                         *
+# * Source is provided to this software because we believe users have a     *
+# * right to know exactly what a program is going to do before they run it. *
+# * This also allows you to audit the software for security holes (none     *
+# * have been found so far).                                                *
+# *                                                                         *
+# * Source code also allows you to port Nmap to new platforms, fix bugs,    *
+# * and add new features.  You are highly encouraged to send your changes   *
+# * to the dev@nmap.org mailing list for possible incorporation into the    *
+# * main distribution.  By sending these changes to Fyodor or one of the    *
+# * Insecure.Org development mailing lists, or checking them into the Nmap  *
+# * source code repository, it is understood (unless you specify otherwise) *
+# * that you are offering the Nmap Project (Insecure.Com LLC) the           *
+# * unlimited, non-exclusive right to reuse, modify, and relicense the      *
+# * code.  Nmap will always be available Open Source, but this is important *
+# * because the inability to relicense code has caused devastating problems *
+# * for other Free Software projects (such as KDE and NASM).  We also       *
+# * occasionally relicense the code to third parties as discussed above.    *
+# * If you wish to specify special license conditions of your               *
+# * contributions, just say so when you send them.                          *
+# *                                                                         *
+# * This program is distributed in the hope that it will be useful, but     *
+# * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Nmap      *
+# * license file for more details (it's in a COPYING file included with     *
+# * Nmap, and also available from https://svn.nmap.org/nmap/COPYING         *
+# *                                                                         *
+# ***************************************************************************/
 
 import gtk
 import math
@@ -42,7 +143,6 @@ OPTIONS = ['address',
 REFRESH_RATE = 500
 
 
-
 class ControlWidget(BWVBox):
     """
     """
@@ -56,7 +156,6 @@ class ControlWidget(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -71,6 +170,13 @@ class ControlWidget(BWVBox):
         self.bw_pack_start_noexpand_nofill(self.__view)
 
 
+def try_set_tooltip_text(widget, text):
+    try:
+        widget.set_tooltip_text(text)
+    except AttributeError:
+        # The set_tooltip_text method was introduced in PyGTK 2.12.
+        pass
+
 
 class ControlAction(BWExpander):
     """
@@ -78,14 +184,13 @@ class ControlAction(BWExpander):
     def __init__(self, radialnet):
         """
         """
-        BWExpander.__init__(self, 'Action')
+        BWExpander.__init__(self, _('Action'))
         self.set_expanded(True)
 
         self.radialnet = radialnet
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -93,10 +198,8 @@ class ControlAction(BWExpander):
         self.__tbox.bw_set_spacing(0)
         self.__vbox = BWVBox()
 
-        self.__tooltips = gtk.Tooltips()
-
         self.__jump_to = gtk.RadioToolButton(None, gtk.STOCK_JUMP_TO)
-        self.__jump_to.set_tooltip(self.__tooltips, 'Change focus')
+        try_set_tooltip_text(self.__jump_to, 'Change focus')
         self.__jump_to.connect('toggled',
                                self.__change_pointer,
                                POINTER_JUMP_TO)
@@ -109,28 +212,28 @@ class ControlAction(BWExpander):
             self.__info.set_label(_("Info"))
         else:
             self.__info = gtk.RadioToolButton(self.__jump_to, info_icon)
-        self.__info.set_tooltip(self.__tooltips, 'Show information')
+        try_set_tooltip_text(self.__info, 'Show information')
         self.__info.connect('toggled',
                             self.__change_pointer,
                             POINTER_INFO)
 
         self.__group = gtk.RadioToolButton(self.__jump_to, gtk.STOCK_ADD)
-        self.__group.set_tooltip(self.__tooltips, 'Group children')
+        try_set_tooltip_text(self.__group, 'Group children')
         self.__group.connect('toggled',
                              self.__change_pointer,
                              POINTER_GROUP)
 
         self.__region = gtk.RadioToolButton(self.__jump_to,
                                             gtk.STOCK_SELECT_COLOR)
-        self.__region.set_tooltip(self.__tooltips, 'Fill region')
+        try_set_tooltip_text(self.__region, 'Fill region')
         self.__region.connect('toggled',
                               self.__change_pointer,
                               POINTER_FILL)
 
         self.__region_color = gtk.combo_box_new_text()
-        self.__region_color.append_text('Red')
-        self.__region_color.append_text('Yellow')
-        self.__region_color.append_text('Green')
+        self.__region_color.append_text(_('Red'))
+        self.__region_color.append_text(_('Yellow'))
+        self.__region_color.append_text(_('Green'))
         self.__region_color.connect('changed', self.__change_region)
         self.__region_color.set_active(self.radialnet.get_region_color())
 
@@ -148,7 +251,6 @@ class ControlAction(BWExpander):
         self.__region_color.set_no_show_all(True)
         self.__region_color.hide()
 
-
     def __change_pointer(self, widget, pointer):
         """
         """
@@ -160,14 +262,12 @@ class ControlAction(BWExpander):
         else:
             self.__region_color.hide()
 
-
     def __change_region(self, widget):
         """
         """
         self.radialnet.set_region_color(self.__region_color.get_active())
 
 
-
 class ControlVariableWidget(gtk.DrawingArea):
     """
     """
@@ -202,7 +302,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         gobject.timeout_add(REFRESH_RATE, self.verify_value)
 
-
     def verify_value(self):
         """
         """
@@ -213,7 +312,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         return True
 
-
     def button_press(self, widget, event):
         """
         """
@@ -226,7 +324,6 @@ class ControlVariableWidget(gtk.DrawingArea):
             self.__active_increment = True
             self.__increment_value()
 
-
     def button_release(self, widget, event):
         """
         """
@@ -237,7 +334,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-
     def motion_notify(self, widget, event):
         """
         Drawing callback
@@ -248,7 +344,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         @rtype: boolean
         @return: Indicator of the event propagation
         """
-        if self.__active_increment == True:
+        if self.__active_increment:
 
             xc, yc = self.__center_of_widget
             x, _ = self.get_pointer()
@@ -258,7 +354,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-
     def expose(self, widget, event):
         """
         Drawing callback
@@ -276,7 +371,6 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         return True
 
-
     def __draw(self):
         """
         """
@@ -289,7 +383,7 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         # draw line
         self.context.set_line_width(1)
-        self.context.set_dash([1,2])
+        self.context.set_dash([1, 2])
         self.context.move_to(self.__radius,
                              yc + self.__radius)
         self.context.line_to(2 * xc - 5,
@@ -297,7 +391,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.stroke()
 
         # draw text
-        self.context.set_dash([1,0])
+        self.context.set_dash([1, 0])
         self.context.set_font_size(10)
 
         width = self.context.text_extents(self.__variable_name)[2]
@@ -315,7 +409,7 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.arc(xc + self.__pointer_position,
                          yc + self.__radius,
                          self.__radius, 0, 2 * math.pi)
-        if self.__active_increment == True:
+        if self.__active_increment:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
         else:
             self.context.set_source_rgb(1.0, 1.0, 1.0)
@@ -323,18 +417,13 @@ class ControlVariableWidget(gtk.DrawingArea):
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.stroke()
 
-
     def __button_is_clicked(self, pointer):
         """
         """
         xc, yc = self.__center_of_widget
         center = (xc, yc + self.__radius)
 
-        if geometry.is_in_circle(pointer, 6, center) == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, 6, center)
 
     def __increment_value(self):
         """
@@ -343,25 +432,22 @@ class ControlVariableWidget(gtk.DrawingArea):
 
         self.queue_draw()
 
-        if self.__active_increment == True:
+        if self.__active_increment:
 
             gobject.timeout_add(self.__increment_time,
                                 self.__increment_value)
 
-
     def set_value_function(self, value):
         """
         """
         self.__value = value
 
-
     def set_update_function(self, update):
         """
         """
         self.__update = update
 
 
-
 class ControlVariable(BWHBox):
     """
     """
@@ -380,7 +466,6 @@ class ControlVariable(BWHBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -411,14 +496,12 @@ class ControlVariable(BWHBox):
         self.bw_pack_start_expand_fill(self.__control)
         self.bw_pack_start_noexpand_nofill(self.__right_button)
 
-
     def __pressed(self, widget, increment):
         """
         """
         self.__increment = True
         self.__increment_function(increment)
 
-
     def __increment_function(self, increment):
         """
         """
@@ -431,15 +514,12 @@ class ControlVariable(BWHBox):
                                 self.__increment_function,
                                 increment)
 
-
     def __released(self, widget):
         """
         """
         self.__increment = False
 
 
-
-
 class ControlFisheye(BWVBox):
     """
     """
@@ -454,13 +534,12 @@ class ControlFisheye(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
         self.__params = BWHBox()
 
-        self.__fisheye_label = gtk.Label('<b>Fisheye</b> on ring')
+        self.__fisheye_label = gtk.Label(_('<b>Fisheye</b> on ring'))
         self.__fisheye_label.set_use_markup(True)
 
         self.__ring = gtk.Adjustment(0, 0, self.__ring_max_value, 0.01, 0.01)
@@ -475,12 +554,12 @@ class ControlFisheye(BWVBox):
         self.__ring_scale.set_draw_value(False)
         self.__ring_scale.set_update_policy(gtk.UPDATE_CONTINUOUS)
 
-        self.__interest_label = gtk.Label('with interest factor')
+        self.__interest_label = gtk.Label(_('with interest factor'))
         self.__interest = gtk.Adjustment(0, 0, 10, 0.01)
         self.__interest_spin = gtk.SpinButton(self.__interest)
         self.__interest_spin.set_digits(2)
 
-        self.__spread_label = gtk.Label('and spread factor')
+        self.__spread_label = gtk.Label(_('and spread factor'))
         self.__spread = gtk.Adjustment(0, -1.0, 1.0, 0.01, 0.01)
         self.__spread_spin = gtk.SpinButton(self.__spread)
         self.__spread_spin.set_digits(2)
@@ -501,7 +580,6 @@ class ControlFisheye(BWVBox):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_fisheye)
 
-
     def __update_fisheye(self):
         """
         """
@@ -543,7 +621,6 @@ class ControlFisheye(BWVBox):
 
         return True
 
-
     def active_fisheye(self):
         """
         """
@@ -551,13 +628,11 @@ class ControlFisheye(BWVBox):
         self.__change_ring()
         self.__change_interest()
 
-
     def deactive_fisheye(self):
         """
         """
         self.radialnet.set_fisheye(False)
 
-
     def __change_ring(self, widget=None):
         """
         """
@@ -566,7 +641,6 @@ class ControlFisheye(BWVBox):
         else:
             self.__ring.set_value(self.radialnet.get_fisheye_ring())
 
-
     def __change_interest(self, widget=None):
         """
         """
@@ -575,7 +649,6 @@ class ControlFisheye(BWVBox):
         else:
             self.__interest.set_value(self.radialnet.get_fisheye_interest())
 
-
     def __change_spread(self, widget=None):
         """
         """
@@ -585,27 +658,26 @@ class ControlFisheye(BWVBox):
             self.__spread.set_value(self.radialnet.get_fisheye_spread())
 
 
-
 class ControlInterpolation(BWExpander):
     """
     """
     def __init__(self, radialnet):
         """
         """
-        BWExpander.__init__(self, 'Interpolation')
+        BWExpander.__init__(self, _('Interpolation'))
 
         self.radialnet = radialnet
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
         self.__vbox = BWVBox()
 
-        self.__cartesian_radio = gtk.RadioButton(None, 'Cartesian')
-        self.__polar_radio = gtk.RadioButton(self.__cartesian_radio, 'Polar')
+        self.__cartesian_radio = gtk.RadioButton(None, _('Cartesian'))
+        self.__polar_radio = gtk.RadioButton(
+                self.__cartesian_radio, _('Polar'))
         self.__cartesian_radio.connect('toggled',
                                        self.__change_system,
                                        INTERPOLATION_CARTESIAN)
@@ -618,7 +690,7 @@ class ControlInterpolation(BWExpander):
         self.__system_box.bw_pack_start_noexpand_nofill(self.__cartesian_radio)
 
         self.__frames_box = BWHBox()
-        self.__frames_label = gtk.Label('Frames')
+        self.__frames_label = gtk.Label(_('Frames'))
         self.__frames_label.set_alignment(0.0, 0.5)
         self.__frames = gtk.Adjustment(self.radialnet.get_number_of_frames(),
                                        1,
@@ -636,7 +708,6 @@ class ControlInterpolation(BWExpander):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_animation)
 
-
     def __update_animation(self):
         """
         """
@@ -650,7 +721,6 @@ class ControlInterpolation(BWExpander):
 
         return True
 
-
     def __change_system(self, widget, value):
         """
         """
@@ -664,7 +734,6 @@ class ControlInterpolation(BWExpander):
             else:
                 self.__polar_radio.set_active(True)
 
-
     def __change_frames(self, widget):
         """
         """
@@ -672,28 +741,26 @@ class ControlInterpolation(BWExpander):
             self.__frames.set_value(self.radialnet.get_number_of_frames())
 
 
-
 class ControlLayout(BWExpander):
     """
     """
     def __init__(self, radialnet):
         """
         """
-        BWExpander.__init__(self, 'Layout')
+        BWExpander.__init__(self, _('Layout'))
 
         self.radialnet = radialnet
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
         self.__hbox = BWHBox()
 
         self.__layout = gtk.combo_box_new_text()
-        self.__layout.append_text('Symmetric')
-        self.__layout.append_text('Weighted')
+        self.__layout.append_text(_('Symmetric'))
+        self.__layout.append_text(_('Weighted'))
         self.__layout.set_active(self.radialnet.get_layout())
         self.__layout.connect('changed', self.__change_layout)
         self.__force = gtk.ToolButton(gtk.STOCK_REFRESH)
@@ -706,7 +773,6 @@ class ControlLayout(BWExpander):
 
         self.__check_layout()
 
-
     def __check_layout(self):
         """
         """
@@ -718,14 +784,12 @@ class ControlLayout(BWExpander):
 
         return True
 
-
     def __force_update(self, widget):
         """
         """
         self.__fisheye_ring = self.radialnet.get_fisheye_ring()
         self.radialnet.update_layout()
 
-
     def __change_layout(self, widget):
         """
         """
@@ -736,7 +800,6 @@ class ControlLayout(BWExpander):
             self.__check_layout()
 
 
-
 class ControlRingGap(BWVBox):
     """
     """
@@ -749,15 +812,14 @@ class ControlRingGap(BWVBox):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
-        self.__radius = ControlVariable('Ring gap',
+        self.__radius = ControlVariable(_('Ring gap'),
                                         self.radialnet.get_ring_gap,
                                         self.radialnet.set_ring_gap)
 
-        self.__label = gtk.Label('Lower ring gap')
+        self.__label = gtk.Label(_('Lower ring gap'))
         self.__label.set_alignment(0.0, 0.5)
         self.__adjustment = gtk.Adjustment(self.radialnet.get_min_ring_gap(),
                                            0,
@@ -773,7 +835,6 @@ class ControlRingGap(BWVBox):
         self.bw_pack_start_noexpand_nofill(self.__radius)
         self.bw_pack_start_noexpand_nofill(self.__lower_hbox)
 
-
     def __change_lower(self, widget):
         """
         """
@@ -781,7 +842,6 @@ class ControlRingGap(BWVBox):
             self.__adjustment.set_value(self.radialnet.get_min_ring_gap())
 
 
-
 class ControlOptions(BWScrolledWindow):
     """
     """
@@ -797,7 +857,6 @@ class ControlOptions(BWScrolledWindow):
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
@@ -838,23 +897,23 @@ class ControlOptions(BWScrolledWindow):
 
         gobject.timeout_add(REFRESH_RATE, self.__update_options)
 
-
     def __update_options(self):
         """
         """
         model = self.__liststore
 
         model[OPTIONS.index('address')][0] = self.radialnet.get_show_address()
-        model[OPTIONS.index('hostname')][0] = self.radialnet.get_show_hostname()
+        model[OPTIONS.index('hostname')][0] = \
+                self.radialnet.get_show_hostname()
         model[OPTIONS.index('icon')][0] = self.radialnet.get_show_icon()
         model[OPTIONS.index('latency')][0] = self.radialnet.get_show_latency()
         model[OPTIONS.index('ring')][0] = self.radialnet.get_show_ring()
         model[OPTIONS.index('region')][0] = self.radialnet.get_show_region()
-        model[OPTIONS.index('slow in/out')][0] = self.radialnet.get_slow_inout()
+        model[OPTIONS.index('slow in/out')][0] = \
+                self.radialnet.get_slow_inout()
 
         return True
 
-
     def __change_option(self, cell, option, model):
         """
         """
@@ -883,27 +942,25 @@ class ControlOptions(BWScrolledWindow):
             self.radialnet.set_slow_inout(model[option][0])
 
 
-
 class ControlView(BWExpander):
     """
     """
     def __init__(self, radialnet):
         """
         """
-        BWExpander.__init__(self, 'View')
+        BWExpander.__init__(self, _('View'))
         self.set_expanded(True)
 
         self.radialnet = radialnet
 
         self.__create_widgets()
 
-
     def __create_widgets(self):
         """
         """
         self.__vbox = BWVBox(spacing=0)
 
-        self.__zoom = ControlVariable('Zoom',
+        self.__zoom = ControlVariable(_('Zoom'),
                                       self.radialnet.get_zoom,
                                       self.radialnet.set_zoom)
 
@@ -921,7 +978,6 @@ class ControlView(BWExpander):
         self.bw_add(self.__vbox)
 
 
-
 class ControlNavigation(gtk.DrawingArea):
     """
     """
@@ -942,12 +998,12 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.__move_position = (0, 0)
         self.__move_addition = [(-1, 0),
-                                (-1,-1),
-                                ( 0,-1),
-                                ( 1,-1),
-                                ( 1, 0),
-                                ( 1, 1),
-                                ( 0, 1),
+                                (-1, -1),
+                                (0, -1),
+                                (1, -1),
+                                (1, 0),
+                                (1, 1),
+                                (0, 1),
                                 (-1, 1)]
 
         self.__move_factor = 1
@@ -981,7 +1037,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.__rotate_node.set_coordinate(40, self.radialnet.get_rotation())
 
-
     def key_press(self, widget, event):
         """
         """
@@ -991,7 +1046,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return True
 
-
     def key_release(self, widget, event):
         """
         """
@@ -1001,13 +1055,11 @@ class ControlNavigation(gtk.DrawingArea):
 
         return True
 
-
     def enter_notify(self, widget, event):
         """
         """
         return False
 
-
     def leave_notify(self, widget, event):
         """
         """
@@ -1015,7 +1067,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def button_press(self, widget, event):
         """
         Drawing callback
@@ -1030,20 +1081,20 @@ class ControlNavigation(gtk.DrawingArea):
 
         direction = False
 
-        if self.__rotate_is_clicked(pointer) == True:
+        if self.__rotate_is_clicked(pointer):
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__rotating = True
 
         direction = self.__move_is_clicked(pointer)
 
-        if direction != None and self.__moving == None:
+        if direction is not None and self.__moving is None:
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__moving = direction
             self.__move_in_direction(direction)
 
-        if self.__center_is_clicked(pointer) == True:
+        if self.__center_is_clicked(pointer):
 
             event.window.set_cursor(gtk.gdk.Cursor(gtk.gdk.HAND2))
             self.__centering = True
@@ -1054,7 +1105,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def button_release(self, widget, event):
         """
         Drawing callback
@@ -1076,7 +1126,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def motion_notify(self, widget, event):
         """
         Drawing callback
@@ -1093,7 +1142,7 @@ class ControlNavigation(gtk.DrawingArea):
         status = not self.radialnet.is_in_animation()
         status = status and not self.radialnet.is_empty()
 
-        if self.__rotating == True and status:
+        if self.__rotating and status:
 
             r, t = self.__rotate_node.get_coordinate()
             t = math.degrees(math.atan2(yc - y, x - xc))
@@ -1105,9 +1154,8 @@ class ControlNavigation(gtk.DrawingArea):
             self.__rotate_node.set_coordinate(r, t)
 
             self.queue_draw()
-        
-        return False
 
+        return False
 
     def expose(self, widget, event):
         """
@@ -1126,7 +1174,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw_rotate_control(self):
         """
         """
@@ -1137,7 +1184,7 @@ class ControlNavigation(gtk.DrawingArea):
         # draw text
         self.context.set_font_size(10)
         self.context.move_to(xc - 49, yc - 48)
-        self.context.show_text("Navigation")
+        self.context.show_text(_("Navigation"))
 
         width = self.context.text_extents(str(int(t)))[2]
         self.context.move_to(xc + 49 - width - 2, yc - 48)
@@ -1146,17 +1193,17 @@ class ControlNavigation(gtk.DrawingArea):
         self.context.stroke()
 
         # draw arc
-        self.context.set_dash([1,2])
+        self.context.set_dash([1, 2])
         self.context.arc(xc, yc, 40, 0, 2 * math.pi)
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.set_line_width(1)
         self.context.stroke()
 
         # draw node
-        self.context.set_dash([1,0])
+        self.context.set_dash([1, 0])
         self.context.arc(xc + x, yc - y, self.__rotate_radius, 0, 2 * math.pi)
 
-        if self.__rotating == True:
+        if self.__rotating:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
 
         else:
@@ -1169,14 +1216,13 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw_move_control(self):
         """
         """
         xc, yc = self.__center_of_widget
         pc = PolarCoordinate()
 
-        self.context.set_dash([1,1])
+        self.context.set_dash([1, 1])
         self.context.arc(xc, yc, 23, 0, 2 * math.pi)
         self.context.set_source_rgb(0.0, 0.0, 0.0)
         self.context.set_line_width(1)
@@ -1186,14 +1232,15 @@ class ControlNavigation(gtk.DrawingArea):
 
             pc.set_coordinate(23, 45 * i)
             x, y = pc.to_cartesian()
-        
-            self.context.set_dash([1,1])
+
+            self.context.set_dash([1, 1])
             self.context.move_to(xc, yc)
             self.context.line_to(xc + x, yc - y)
             self.context.stroke()
 
-            self.context.set_dash([1,0])
-            self.context.arc(xc + x, yc - y, self.__move_radius, 0, 2 * math.pi)
+            self.context.set_dash([1, 0])
+            self.context.arc(
+                    xc + x, yc - y, self.__move_radius, 0, 2 * math.pi)
 
             if i == self.__moving:
                 self.context.set_source_rgb(0.0, 0.0, 0.0)
@@ -1206,7 +1253,7 @@ class ControlNavigation(gtk.DrawingArea):
 
         self.context.arc(xc, yc, 6, 0, 2 * math.pi)
 
-        if self.__centering == True:
+        if self.__centering:
             self.context.set_source_rgb(0.0, 0.0, 0.0)
         else:
             self.context.set_source_rgb(1.0, 1.0, 1.0)
@@ -1217,7 +1264,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __draw(self):
         """
         Drawing method
@@ -1233,11 +1279,10 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __move_in_direction(self, direction):
         """
         """
-        if self.__moving != None:
+        if self.__moving is not None:
 
             bx, by = self.__move_position
             ax, ay = self.__move_addition[direction]
@@ -1255,7 +1300,6 @@ class ControlNavigation(gtk.DrawingArea):
 
         return False
 
-
     def __rotate_is_clicked(self, pointer):
         """
         """
@@ -1263,26 +1307,13 @@ class ControlNavigation(gtk.DrawingArea):
         xc, yc = self.__center_of_widget
 
         center = (xc + xn, yc - yn)
-        result = geometry.is_in_circle(pointer, self.__rotate_radius, center)
-
-        if result == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, self.__rotate_radius, center)
 
     def __center_is_clicked(self, pointer):
         """
         """
-        result = geometry.is_in_circle(pointer,
-                                       self.__move_radius,
-                                       self.__center_of_widget)
-
-        if result == True:
-            return True
-
-        return False
-
+        return geometry.is_in_circle(pointer, self.__move_radius,
+                self.__center_of_widget)
 
     def __move_is_clicked(self, pointer):
         """
@@ -1294,15 +1325,9 @@ class ControlNavigation(gtk.DrawingArea):
 
             pc.set_coordinate(23, 45 * i)
             x, y = pc.to_cartesian()
-        
-            center = (xc + x, yc - y)
-            result = geometry.is_in_circle(pointer,
-                                           self.__move_radius,
-                                           center)
 
-            if result == True:
+            center = (xc + x, yc - y)
+            if geometry.is_in_circle(pointer, self.__move_radius, center):
                 return i
 
         return None
-
-
