@@ -2,7 +2,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -10,7 +10,7 @@
 # * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
 # * modify, and redistribute this software under certain conditions.  If    *
 # * you wish to embed Nmap technology into proprietary software, we sell    *
-# * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
 # * vendors already license Nmap technology such as host discovery, port    *
 # * scanning, OS detection, version detection, and the Nmap Scripting       *
 # * Engine.                                                                 *
@@ -66,7 +66,7 @@
 # * obeying all GPL rules and restrictions.  For example, source code of    *
 # * the whole work must be provided and free redistribution must be         *
 # * allowed.  All GPL references to "this License", are to be treated as    *
-# * including the special and conditions of the license text as well.       *
+# * including the terms and conditions of this license text as well.        *
 # *                                                                         *
 # * Because this license imposes special exceptions to the GPL, Covered     *
 # * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -84,12 +84,12 @@
 # * applications and appliances.  These contracts have been sold to dozens  *
 # * of software vendors, and generally include a perpetual license as well  *
 # * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -128,7 +128,7 @@ from zenmapCore.Paths import Path
 
 
 FORMAT_RGBA = 4
-FORMAT_RGB  = 3
+FORMAT_RGB = 3
 
 
 def get_pixels_for_cairo_image_surface(pixbuf):
@@ -144,16 +144,16 @@ def get_pixels_for_cairo_image_surface(pixbuf):
     j = 0
     while i < len(pixbuf.get_pixels()):
 
-        b, g, r = pixbuf.get_pixels()[i:i+FORMAT_RGB]
+        b, g, r = pixbuf.get_pixels()[i:i + FORMAT_RGB]
 
         if format == FORMAT_RGBA:
             a = pixbuf.get_pixels()[i + FORMAT_RGBA - 1]
         elif format == FORMAT_RGB:
             a = '\xff'
         else:
-            raise TypeError, 'unknown image format'
+            raise TypeError('unknown image format')
 
-        data[j:j+FORMAT_RGBA] = array.ArrayType('c', [r, g, b, a])
+        data[j:j + FORMAT_RGBA] = array.ArrayType('c', [r, g, b, a])
 
         i += format
         j += FORMAT_RGBA
@@ -170,37 +170,34 @@ class Image:
         self.__path = path
         self.__cache = dict()
 
-
     def set_path(self, path):
         """
         """
         self.__path = path
 
-
     def get_pixbuf(self, icon, image_type='png'):
         """
         """
-        if self.__path == None:
+        if self.__path is None:
             return False
 
         if icon + image_type not in self.__cache.keys():
 
             file = self.get_icon(icon, image_type)
-            self.__cache[icon + image_type] = gtk.gdk.pixbuf_new_from_file(file)
+            self.__cache[icon + image_type] = \
+                    gtk.gdk.pixbuf_new_from_file(file)
 
         return self.__cache[icon + image_type]
 
-
     def get_icon(self, icon, image_type='png'):
         """
         """
-        if self.__path == None:
+        if self.__path is None:
             return False
 
         return os.path.join(self.__path, icon + "." + image_type)
 
 
-
 class Pixmaps(Image):
     """
     """
@@ -210,7 +207,6 @@ class Pixmaps(Image):
         Image.__init__(self, os.path.join(Path.pixmaps_dir, "radialnet"))
 
 
-
 class Icons(Image):
     """
     """
@@ -220,7 +216,6 @@ class Icons(Image):
         Image.__init__(self, os.path.join(Path.pixmaps_dir, "radialnet"))
 
 
-
 class Application(Image):
     """
     """
