@@ -3,7 +3,7 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2013 Insecure.Com LLC. Nmap is    *
+# * The Nmap Security Scanner is (C) 1996-2014 Insecure.Com LLC. Nmap is    *
 # * also a registered trademark of Insecure.Com LLC.  This program is free  *
 # * software; you may redistribute and/or modify it under the terms of the  *
 # * GNU General Public License as published by the Free Software            *
@@ -11,7 +11,7 @@
 # * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
 # * modify, and redistribute this software under certain conditions.  If    *
 # * you wish to embed Nmap technology into proprietary software, we sell    *
-# * alternative licenses (contact sales@insecure.com).  Dozens of software  *
+# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
 # * vendors already license Nmap technology such as host discovery, port    *
 # * scanning, OS detection, version detection, and the Nmap Scripting       *
 # * Engine.                                                                 *
@@ -67,7 +67,7 @@
 # * obeying all GPL rules and restrictions.  For example, source code of    *
 # * the whole work must be provided and free redistribution must be         *
 # * allowed.  All GPL references to "this License", are to be treated as    *
-# * including the special and conditions of the license text as well.       *
+# * including the terms and conditions of this license text as well.        *
 # *                                                                         *
 # * Because this license imposes special exceptions to the GPL, Covered     *
 # * Work may not be combined (even as part of a larger work) with plain GPL *
@@ -85,12 +85,12 @@
 # * applications and appliances.  These contracts have been sold to dozens  *
 # * of software vendors, and generally include a perpetual license as well  *
 # * as providing for priority support and updates.  They also fund the      *
-# * continued development of Nmap.  Please email sales@insecure.com for     *
-# * further information.                                                    *
+# * continued development of Nmap.  Please email sales@nmap.com for further *
+# * information.                                                            *
 # *                                                                         *
-# * If you received these files with a written license agreement or         *
-# * contract stating terms other than the terms above, then that            *
-# * alternative license agreement takes precedence over these comments.     *
+# * If you have received a written license agreement or contract for        *
+# * Covered Software stating terms other than these, you may choose to use  *
+# * and redistribute Covered Software under those terms instead of these.   *
 # *                                                                         *
 # * Source is provided to this software because we believe users have a     *
 # * right to know exactly what a program is going to do before they run it. *
@@ -121,9 +121,11 @@
 # ***************************************************************************/
 
 from os.path import exists
-from ConfigParser import ConfigParser, DEFAULTSECT, NoOptionError, NoSectionError
+from ConfigParser import ConfigParser, DEFAULTSECT, NoOptionError, \
+        NoSectionError
 from zenmapCore.UmitLogging import log
 
+
 class UmitConfigParser(ConfigParser):
     filenames = None
     fp = None
@@ -158,9 +160,11 @@ class UmitConfigParser(ConfigParser):
                 if len(self.filenames) == 1:
                     filename = self.filenames[0]
                 else:
-                    raise ValueError("UmitConfigParser can't handle a list of filenames: %s" % self.filenames)
+                    raise ValueError("UmitConfigParser can't handle a list "
+                            "of filenames: %s" % self.filenames)
             else:
-                raise ValueError("UmitConfigParser can't handle a filename of type %s: %s" % (type(self.filenames), self.filenames))
+                raise ValueError("UmitConfigParser can't handle a filename of "
+                        "type %s: %s" % (type(self.filenames), self.filenames))
             self.write(open(filename, 'w'))
         elif self.fp:
             self.write(self.fp)
@@ -188,6 +192,7 @@ class UmitConfigParser(ConfigParser):
                              (key, str(value).replace('\n', '\n\t')))
             fp.write("\n")
 
+
 def test_umit_conf_content(filename):
     parser = ConfigParser()
     parser.read(filename)
